@@ -52,6 +52,7 @@ have_rar (void)
 
 /* -- list -- */
 
+
 static time_t
 mktime_from_string (char *date_s, 
 		    char *time_s)
@@ -131,8 +132,6 @@ process_line (char     *line,
 		}
 		
 		fdata->link = NULL;
-		
-		fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 		fdata->path = remove_level_from_path (fdata->full_path);
 
 	} else {
@@ -144,19 +143,30 @@ process_line (char     *line,
 		
 		fields = split_line (line, 6);
 
-		if ((fdata->name == NULL)
-		    || (*fdata->name == '\0') 
-		    || (fields[5][1] == 'D') 
-		    || (fields[5][0] == 'd')) {
-			file_data_free (fdata);
-		} else {
-			fdata->size = g_ascii_strtoull (fields[0], NULL, 10);
-			fdata->modified = mktime_from_string (fields[3], fields[4]); 
-			comm->file_list = g_list_prepend (comm->file_list, fdata);
-		}
-		g_strfreev (fields);
+		fdata->size = g_ascii_strtoull (fields[0], NULL, 10);
+		fdata->modified = mktime_from_string (fields[3], fields[4]);
 
+		if ((fields[5][1] == 'D') || (fields[5][0] == 'd')) {
+			gboolean  original_is_full = fdata->original_path == fdata->full_path;
+			char     *path = fdata->full_path;
+						
+			fdata->full_path = g_strconcat (path, "/", NULL);
+			if (original_is_full)
+				fdata->original_path = fdata->full_path;
+			else
+				fdata->original_path = fdata->full_path + 1;
+			fdata->name =  dir_name_from_path (fdata->full_path);
+			
+			fdata->dir = TRUE;
+			
+			g_free (path);
+		} else
+			fdata->name = g_strdup (file_name_from_path (fdata->full_path));
+
+		comm->file_list = g_list_prepend (comm->file_list, fdata);
 		rar_comm->fdata = NULL;
+		
+		g_strfreev (fields);
 	}
 
 	rar_comm->odd_line = ! rar_comm->odd_line;
@@ -247,7 +257,7 @@ fr_command_rar_add (FRCommand     *comm,
 	add_password_arg (comm, password, FALSE);
 
 	/* disable percentage indicator */
-	fr_process_add_arg (comm->process, "-idp");
+	fr_process_add_arg (comm->process, "-Idp");
 	
 	/* stop switches scanning */
 	fr_process_add_arg (comm->process, "--"); 
@@ -313,7 +323,7 @@ fr_command_rar_extract (FRCommand  *comm,
 	add_password_arg (comm, password, TRUE);
 
 	/* disable percentage indicator */
-	fr_process_add_arg (comm->process, "-idp");
+	fr_process_add_arg (comm->process, "-Idp");
 	
 	/* stop switches scanning */
 	fr_process_add_arg (comm->process, "--"); 
@@ -347,7 +357,7 @@ fr_command_rar_test (FRCommand   *comm,
 	add_password_arg (comm, password, TRUE);
 
 	/* disable percentage indicator */
-	fr_process_add_arg (comm->process, "-idp");
+	fr_process_add_arg (comm->process, "-Idp");
 
 	/* stop switches scanning */
 	fr_process_add_arg (comm->process, "--");
@@ -366,8 +376,7 @@ fr_command_rar_handle_error (FRCommand   *comm,
 			error->type = FR_PROC_ERROR_NONE;
 		else if (error->status == 3)
 			error->type = FR_PROC_ERROR_ASK_PASSWORD;
-	} else if (error->type == FR_PROC_ERROR_EXITED_ABNORMALLY)
-		error->type = FR_PROC_ERROR_ASK_PASSWORD;
+	}
 }
 
 
@@ -398,6 +407,7 @@ fr_command_rar_init (FRCommand *comm)
 
 	comm->propAddCanUpdate             = TRUE; 
 	comm->propAddCanReplace            = TRUE; 
+	comm->propAddCanStoreFolders       = TRUE;
 	comm->propExtractCanAvoidOverwrite = TRUE;
 	comm->propExtractCanSkipOlder      = TRUE;
 	comm->propExtractCanJunkPaths      = TRUE;
